@@ -4,17 +4,20 @@
 #  LICENSE file in the root directory of this source tree.
 
 import textwrap
+import pytest
 import time
 import uuid
 import disco
 from time import sleep
 from disco.core.constants import JobStatus, TaskStatus
 from tests.base_test import BaseTest
+from tests.live import env
 from .env import LIVE_TESTS_TIMEOUT_SECONDS, LIVE_TESTS_JOB_START_WAIT_TIME, LIVE_TESTS_TASKS_RUNNING_WAIT_TIME
 from .utils import get_non_running_tasks
 from disco.core.exceptions import GraphQLRequestException
 
-# @pytest.mark.skipif(env.skip, reason=env.reason)
+
+@pytest.mark.skipif(env.skip, reason=env.reason)
 # TODO: Test with a non-default cluster
 # TODO: Archive jobs on tear-down even if an exception was thrown
 class TestJobsLive(object):
@@ -34,14 +37,14 @@ class TestJobsLive(object):
         constants_file_id = disco.upload_file('constants.txt', 'ZZZ')
         users_repositories = disco.Repository.list_repositories()
         if len(users_repositories) > 0:
-            script_repo_id = users_repositories[0].id;
+            script_repo_id = users_repositories[0].id
             script_file_path = 'aaa'
             job_name = 'Automation Start Job %s' % uuid.uuid4()
             job = disco.Job.create(input_file_ids=[input_file_id],
                                    constants_file_ids=[constants_file_id],
                                    job_name=job_name,
-                                   script_repo_id = script_repo_id,
-                                   script_file_path_in_repo= script_file_path)
+                                   script_repo_id=script_repo_id,
+                                   script_file_path_in_repo=script_file_path)
 
             job_details = job.get_details()
             job_id = job_details.id
